==> Moony_0.5.3.tar.gz: Moony/lib/moony/Moony_Config.php <==
<?php
//
// +--------------------------------------------------------------------+
// | PHP version 4                                                      |
// +--------------------------------------------------------------------+
// | Copyright (c) 2005 The Moony Project                               |
// +--------------------------------------------------------------------+
// | This source file is subject to version 3.00 of the PHP License,    |
// | that is available at http://www.php.net/license/3_0.txt.           |
// | If you did not receive a copy of the PHP license and are unable to |
// | obtain it through the world-wide-web, please send a note to        |
// | license@php.net so we can mail you a copy immediately.             |
// +--------------------------------------------------------------------+
// | Authors: YAMAOKA Hiroyuki <yamaoka@catwalker.jp>                   |
// +--------------------------------------------------------------------+
//

// MoonyΥСɽ
define('MOONY_VERSION', '0.5.3');

// ̾ΤꤵʤΥǥեȥ̾
define('MOONY_DEFAULT_ACTION_NAME', 'Home');

// URLβܤޤǤ򥢥ȤƲ᤹뤫
define('MOONY_EVAL_AS_ACTION_SETTING', 2);

// Ѥ륢󥯥饹ǼƤǥ쥯ȥ
define('MOONY_ACTION_DIR', MOONY_BASE . '/webapp/action');

// 󥯥饹γĥ
define('MOONY_ACTION_EXT', 'php');

// Smarty֤Ƥǥ쥯ȥ
define('MOONY_SMARTY_CLASS', MOONY_BASE . '/lib/smarty/Smarty.class.php');

// SmartyΥƥץ졼ȥե뤬ǼƤǥ쥯ȥ
define('MOONY_SMARTY_TEMPLATE_DIR', MOONY_BASE . '/webapp/template');

// SmartyΥѥѤߥեǼǥ쥯ȥ
define('MOONY_SMARTY_COMPILE_DIR', MOONY_BASE . '/webapp/work');

// SmartyΥåեǼǥ쥯ȥ
define('MOONY_SMARTY_CACHE_DIR', MOONY_BASE . '/webapp/work');

// SmartyΥå嵡ǽ򥢥󥯥饹ʤ˥ǥեȤǻѤ뤫ɤ
define('MOONY_SMARTY_USE_CACHE_WITHOUT_ACTION', true);

// SmartyΥƥץ졼ȥեѹȿǤ뤫ɤ
define('MOONY_SMARTY_COMPILE_CHECK', true);

// SmartyΥƥץ졼ȥեγĥ
define('MOONY_SMARTY_TEMPLATE_EXT', 'tpl');

// ե̾
define('MOONY_LOG_FILE', MOONY_BASE . '/log/moony.log');

// ΥơȤԤɤ
define('MOONY_LOG_ROTATE', true);

// ɬפincludeԤ
require_once MOONY_BASE . '/lib/moony/core/Moony_Controller.php';
require_once MOONY_BASE . '/lib/moony/core/Moony_Request.php';
require_once MOONY_BASE . '/lib/moony/core/Moony_Session.php';
require_once MOONY_BASE . '/lib/moony/core/Moony_View.php';
require_once MOONY_BASE . '/lib/moony/core/Moony_Action.php';
require_once MOONY_BASE . '/lib/moony/util/Moony_Logger.php';
require_once MOONY_BASE . '/lib/moony/util/Moony_ErrorHandler.php';
require_once MOONY_SMARTY_CLASS;
?>

==> Moony_0.6.0.tar.gz: Moony/lib/moony/Moony_Config.php <==
<?php
//
// +--------------------------------------------------------------------+
// | PHP version 4                                                      |
// +--------------------------------------------------------------------+
// | Copyright (c) 2005 The Moony Project                               |
// +--------------------------------------------------------------------+
// | This source file is subject to version 3.00 of the PHP License,    |
// | that is available at http://www.php.net/license/3_0.txt.           |
// | If you did not receive a copy of the PHP license and are unable to |
// | obtain it through the world-wide-web, please send a note to        |
// | license@php.net so we can mail you a copy immediately.             |
// +--------------------------------------------------------------------+
// | Authors: YAMAOKA Hiroyuki <yamaoka@catwalker.jp>                   |
// +--------------------------------------------------------------------+
//

// MoonyΥСɽ
define('MOONY_VERSION', '0.6.0');

// ̾ΤꤵʤΥǥեȥ̾
define('MOONY_DEFAULT_ACTION_NAME', 'Home');

// URLβܤޤǤ򥢥ȤƲ᤹뤫
define('MOONY_EVAL_AS_ACTION_SETTING', 2);

// Ѥ륢󥯥饹ǼƤǥ쥯ȥ
define('MOONY_ACTION_DIR', MOONY_ROOT_DIR . '/app/action');

// 󥯥饹γĥ
define('MOONY_ACTION_EXT', 'php');

// Smarty֤Ƥǥ쥯ȥ
define('MOONY_SMARTY_CLASS', MOONY_ROOT_DIR . '/lib/smarty/Smarty.class.php');

// SmartyΥƥץ졼ȥե뤬ǼƤǥ쥯ȥ
define('MOONY_SMARTY_TEMPLATE_DIR', MOONY_ROOT_DIR . '/app/template');

// SmartyΥѥѤߥեǼǥ쥯ȥ
define('MOONY_SMARTY_COMPILE_DIR', MOONY_ROOT_DIR . '/app/work');

// SmartyΥåեǼǥ쥯ȥ
define('MOONY_SMARTY_CACHE_DIR', MOONY_ROOT_DIR . '/app/work');

// SmartyΥå嵡ǽ򥢥󥯥饹ʤ˥ǥեȤǻѤ뤫ɤ
define('MOONY_SMARTY_USE_CACHE_WITHOUT_ACTION', true);

// SmartyΥƥץ졼ȥեѹȿǤ뤫ɤ
define('MOONY_SMARTY_COMPILE_CHECK', true);

// SmartyΥƥץ졼ȥեγĥ
define('MOONY_SMARTY_TEMPLATE_EXT', 'tpl');

// ե̾
define('MOONY_LOG_FILE', MOONY_ROOT_DIR . '/log/moony.log');

// ΥơȤԤɤ
define('MOONY_LOG_ROTATE', true);

// ɬפincludeԤ
require_once MOONY_ROOT_DIR . '/lib/moony/core/Moony_Context.php';
require_once MOONY_ROOT_DIR . '/lib/moony/core/Moony_Controller.php';
require_once MOONY_ROOT_DIR . '/lib/moony/core/Moony_Request.php';
require_once MOONY_ROOT_DIR . '/lib/moony/core/Moony_Session.php';
require_once MOONY_ROOT_DIR . '/lib/moony/core/Moony_View.php';
require_once MOONY_ROOT_DIR . '/lib/moony/core/Moony_Action.php';
require_once MOONY_ROOT_DIR . '/lib/moony/util/Moony_Logger.php';
require_once MOONY_ROOT_DIR . '/lib/moony/util/Moony_ErrorHandler.php';
require_once MOONY_SMARTY_CLASS;
?>
